@@ -25,6 +25,7 @@ class DiscordWebhook:
         :keyword file: file contents
         :keyword filename: file name
         :keyword embeds: list of embedded rich content
+        :keyword allowed_mentions: allowed mentions for the message
         :keyword proxies: dict of proxies
         """
         self.url = url
@@ -34,7 +35,8 @@ class DiscordWebhook:
         self.tts = kwargs.get("tts", False)
         self.files = kwargs.get("files", dict())
         self.embeds = kwargs.get("embeds", [])
-        self.proxies = kwargs.get("proxies", None)
+        self.proxies = kwargs.get("proxies")
+        self.allowed_mentions = kwargs.get("allowed_mentions")
 
     def add_file(self, file, filename):
         """
@@ -114,7 +116,7 @@ class DiscordWebhook:
         responses = []
         for i, url in enumerate(webhook_urls):
             if bool(self.files) is False:
-                response = requests.post(url, json=self.json, proxies=self.proxies)
+                response = requests.post(url, json=self.json, proxies=self.proxies, params={'wait':True})
             else:
                 self.files["payload_json"] = (None, json.dumps(self.json))
                 response = requests.post(url, files=self.files, proxies=self.proxies)
@@ -134,7 +136,73 @@ class DiscordWebhook:
                     )
                 )
             responses.append(response)
-        return responses[0] if len(responses) == 1 else responses
+        return responses
+
+    def edit(self, sent_webhook):
+        """
+        edits the webhook passed as a response
+        :param sent_webhook: webhook.execute() response
+        :return: Another webhook response
+        """
+        webhook_len = len(sent_webhook)
+        responses = []
+        for i, webhook in enumerate(sent_webhook):
+            url = webhook.url.split('?')[0]  # removes any query params
+            previous_sent_message_id = json.loads(webhook.content.decode('utf-8'))['id']
+            if bool(self.files) is False:
+                response = requests.patch(url+'/messages/'+str(previous_sent_message_id), json=self.json, proxies=self.proxies, params={'wait': True})
+            else:
+                self.files["payload_json"] = (None, json.dumps(self.json))
+                response = requests.patch(url+'/messages/'+str(previous_sent_message_id), files=self.files, proxies=self.proxies)
+            if response.status_code in [200, 204]:
+                logger.debug(
+                    "[{index}/{length}] Webhook edited".format(
+                        index=i + 1,
+                        length=webhook_len,
+                    )
+                )
+            else:
+                logger.error(
+                    "[{index}/{length}] Webhook status code {status_code}: {content}".format(
+                        index=i + 1,
+                        length=webhook_len,
+                        status_code=response.status_code,
+                        content=response.content.decode("utf-8"),
+                    )
+                )
+            responses.append(response)
+        return responses
+
+    def delete(self, sent_webhook):
+        """
+        deletes the webhook passed as a response
+        :param sent_webhook: webhook.execute() response
+        :return: Response
+        """
+        webhook_len = len(sent_webhook)
+        responses = []
+        for i, webhook in enumerate(sent_webhook):
+            url = webhook.url.split('?')[0]  # removes any query params
+            previous_sent_message_id = json.loads(webhook.content.decode('utf-8'))['id']
+            response = requests.delete(url+'/messages/'+str(previous_sent_message_id), proxies=self.proxies)
+            if response.status_code in [200, 204]:
+                logger.debug(
+                    "[{index}/{length}] Webhook deleted".format(
+                        index=i + 1,
+                        length=webhook_len,
+                    )
+                )
+            else:
+                logger.error(
+                    "[{index}/{length}] Webhook status code {status_code}: {content}".format(
+                        index=i + 1,
+                        length=webhook_len,
+                        status_code=response.status_code,
+                        content=response.content.decode("utf-8"),
+                    )
+                )
+            responses.append(response)
+        return responses
 
 
 class DiscordEmbed:
